diff --git a/Classes/MGTwitterEngine.m b/Classes/MGTwitterEngine.m
index 6e7b712..980c75a 100644
--- a/Classes/MGTwitterEngine.m
+++ b/Classes/MGTwitterEngine.m
@@ -11,6 +11,8 @@
 
 #import "NSData+Base64.h"
 
+#import "PTPreferenceManager.h"
+
 #define USE_LIBXML 0
 
 #if YAJL_AVAILABLE
@@ -104,12 +106,12 @@
         _clientVersion = [DEFAULT_CLIENT_VERSION retain];
         _clientURL = [DEFAULT_CLIENT_URL retain];
 		_clientSourceToken = [DEFAULT_CLIENT_TOKEN retain];
-		_APIDomain = [TWITTER_DOMAIN retain];
+		_APIDomain = [[PTPreferenceManager sharedSingleton] twitterBase];
 #if YAJL_AVAILABLE
 		_searchDomain = [TWITTER_SEARCH_DOMAIN retain];
 #endif
 
-        _secureConnection = YES;
+		_secureConnection = [[PTPreferenceManager sharedSingleton] twitterHttps];
 		_clearsCookies = NO;
 #if YAJL_AVAILABLE
 		_deliveryOptions = MGTwitterEngineDeliveryAllResultsOption;
diff --git a/Classes/Pwitter/Preferences/PTPreferenceManager.h b/Classes/Pwitter/Preferences/PTPreferenceManager.h
index 1c3e74a..1d5334e 100644
--- a/Classes/Pwitter/Preferences/PTPreferenceManager.h
+++ b/Classes/Pwitter/Preferences/PTPreferenceManager.h
@@ -56,5 +56,7 @@
 - (int)maxTweets;
 - (void)setHideDockIcon:(BOOL)aFlag;
 - (BOOL)hideDockIcon;
+- (BOOL)twitterHttps;
+- (NSString*)twitterBase;
 
 @end
diff --git a/Classes/Pwitter/Preferences/PTPreferenceManager.m b/Classes/Pwitter/Preferences/PTPreferenceManager.m
index 926d381..df106ea 100644
--- a/Classes/Pwitter/Preferences/PTPreferenceManager.m
+++ b/Classes/Pwitter/Preferences/PTPreferenceManager.m
@@ -39,6 +39,13 @@ static PTPreferenceManager *sharedSingleton;
 
 - (void)setupPreferences {
 	fPrefData = [NSUserDefaults standardUserDefaults];
+	NSDictionary *appDefaults;
+	appDefaults = [NSDictionary
+				   dictionaryWithObject:[NSNumber numberWithBool:YES] forKey:@"twitter_https"];
+	[fPrefData registerDefaults:appDefaults];
+	appDefaults = [NSDictionary
+				   dictionaryWithObject:@"twitter.com" forKey:@"twitter_base"];
+	[fPrefData registerDefaults:appDefaults];
 	if ([fPrefData integerForKey:@"time_interval"] == 0)
 		[fPrefData setInteger:2 forKey:@"time_interval"];
 	if ([fPrefData integerForKey:@"message_interval"] == 0)
@@ -245,4 +252,12 @@ static PTPreferenceManager *sharedSingleton;
 	return lShouldHide;
 }
 
+- (BOOL)twitterHttps {
+	return [fPrefData boolForKey:@"twitter_https"];
+}
+
+- (NSString*)twitterBase {
+	return [fPrefData stringForKey:@"twitter_base"];
+}
+
 @end
